##  Creating Custom Fact Sheet Subtypes
Subtype management simplifies the process of creating subtypes by providing a Add Subtypes button at the top of the fact sheet type configuration page.
Clicking on the Add Subtypes button opens a panel on the right where you provide a unique ID for the subtype being created.
![Adding Fact Sheet Subtypes in Meta Model Configuration](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749db827a4410149f009b6fb9317e6b_LowRes.png)
Adding Fact Sheet Subtypes in Meta Model Configuration
For fact sheets that already have subtypes, additional subtypes can be created using the same button (dropdown menu). This allows for further categorization and customization of data within the fact sheet.
